==> colourvalues_0.3.0.tar.gz: colourvalues/inst/include/colourvalues/palettes/matlab_like2.hpp <==
#ifndef R_COLOURVALUES_MATLAB_LIKE2_H
#define R_COLOURVALUES_MATLAB_LIKE2_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector matlab_like2_red = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0117647058823529,0.0196078431372549,
    0.0313725490196078,0.0392156862745098,0.0509803921568627,0.0588235294117647,
    0.0705882352941176,0.0784313725490196,0.0862745098039216,0.0980392156862745,
    0.109803921568627,0.117647058823529,0.129411764705882,0.137254901960784,
    0.149019607843137,0.156862745098039,0.168627450980392,0.176470588235294,
    0.188235294117647,0.196078431372549,0.207843137254902,0.215686274509804,
    0.227450980392157,0.235294117647059,0.247058823529412,0.254901960784314,
    0.266666666666667,0.274509803921569,0.286274509803922,0.294117647058824,
    0.305882352941176,0.313725490196078,0.325490196078431,0.333333333333333,
    0.345098039215686,0.352941176470588,0.364705882352941,0.372549019607843,
    0.384313725490196,0.392156862745098,0.403921568627451,0.411764705882353,
    0.423529411764706,0.431372549019608,0.443137254901961,0.450980392156863,
    0.462745098039216,0.470588235294118,0.482352941176471,0.490196078431373,
    0.501960784313725,0.509803921568627,0.52156862745098,0.529411764705882,
    0.541176470588235,0.549019607843137,0.56078431372549,0.568627450980392,
    0.576470588235294,0.588235294117647,0.6,0.607843137254902,
    0.619607843137255,0.627450980392157,0.63921568627451,0.647058823529412,
    0.658823529411765,0.666666666666667,0.67843137254902,0.686274509803922,
    0.698039215686274,0.705882352941177,0.717647058823529,0.725490196078431,
    0.733333333333333,0.745098039215686,0.756862745098039,0.764705882352941,
    0.776470588235294,0.784313725490196,0.796078431372549,0.803921568627451,
    0.815686274509804,0.823529411764706,0.835294117647059,0.843137254901961,
    0.854901960784314,0.862745098039216,0.874509803921569,0.882352941176471,
    0.890196078431372,0.901960784313726,0.913725490196078,0.92156862745098,
    0.933333333333333,0.941176470588235,0.952941176470588,0.96078431372549,
    0.972549019607843,0.980392156862745,0.992156862745098,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,0.992156862745098,
    0.980392156862745,0.972549019607843,0.96078431372549,0.952941176470588,
    0.941176470588235,0.933333333333333,0.92156862745098,0.913725490196078,
    0.901960784313726,0.890196078431372,0.882352941176471,0.874509803921569,
    0.862745098039216,0.854901960784314,0.843137254901961,0.835294117647059,
    0.823529411764706,0.815686274509804,0.803921568627451,0.796078431372549,
    0.784313725490196,0.776470588235294,0.764705882352941,0.756862745098039
  };

  const Rcpp::NumericVector matlab_like2_green = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0196078431372549,0.0392156862745098,
    0.0588235294117647,0.0784313725490196,0.0980392156862745,0.117647058823529,
    0.137254901960784,0.156862745098039,0.176470588235294,0.196078431372549,
    0.215686274509804,0.235294117647059,0.254901960784314,0.274509803921569,
    0.294117647058824,0.313725490196078,0.333333333333333,0.352941176470588,
    0.372549019607843,0.392156862745098,0.411764705882353,0.431372549019608,
    0.450980392156863,0.470588235294118,0.490196078431373,0.509803921568627,
    0.529411764705882,0.549019607843137,0.568627450980392,0.588235294117647,
    0.607843137254902,0.627450980392157,0.647058823529412,0.666666666666667,
    0.686274509803922,0.705882352941177,0.725490196078431,0.745098039215686,
    0.764705882352941,0.784313725490196,0.803921568627451,0.823529411764706,
    0.843137254901961,0.862745098039216,0.882352941176471,0.901960784313726,
    0.92156862745098,0.941176470588235,0.96078431372549,0.980392156862745,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,0.980392156862745,
    0.96078431372549,0.941176470588235,0.92156862745098,0.901960784313726,
    0.886274509803922,0.866666666666667,0.847058823529412,0.827450980392157,
    0.807843137254902,0.788235294117647,0.768627450980392,0.749019607843137,
    0.729411764705882,0.709803921568627,0.694117647058824,0.674509803921569,
    0.654901960784314,0.635294117647059,0.615686274509804,0.596078431372549,
    0.576470588235294,0.556862745098039,0.537254901960784,0.517647058823529,
    0.501960784313725,0.482352941176471,0.462745098039216,0.443137254901961,
    0.423529411764706,0.403921568627451,0.384313725490196,0.364705882352941,
    0.345098039215686,0.325490196078431,0.305882352941176,0.290196078431373,
    0.270588235294118,0.250980392156863,0.231372549019608,0.211764705882353,
    0.192156862745098,0.172549019607843,0.152941176470588,0.133333333333333,
    0.113725490196078,0.0980392156862745,0.0784313725490196,0.0588235294117647,
    0.0392156862745098,0.0196078431372549,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  const Rcpp::NumericVector matlab_like2_blue = {
    0.745098039215686,0.756862745098039,0.764705882352941,0.776470588235294,
    0.784313725490196,0.796078431372549,0.803921568627451,0.815686274509804,
    0.823529411764706,0.835294117647059,0.843137254901961,0.854901960784314,
    0.862745098039216,0.874509803921569,0.882352941176471,0.890196078431372,
    0.901960784313726,0.913725490196078,0.92156862745098,0.933333333333333,
    0.941176470588235,0.952941176470588,0.96078431372549,0.972549019607843,
    0.980392156862745,0.992156862745098,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,0.988235294117647,0.980392156862745,
    0.968627450980392,0.96078431372549,0.949019607843137,0.941176470588235,
    0.929411764705882,0.92156862745098,0.909803921568627,0.901960784313726,
    0.890196078431372,0.882352941176471,0.870588235294118,0.862745098039216,
    0.850980392156863,0.843137254901961,0.831372549019608,0.823529411764706,
    0.811764705882353,0.803921568627451,0.792156862745098,0.780392156862745,
    0.772549019607843,0.76078431372549,0.752941176470588,0.741176470588235,
    0.733333333333333,0.72156862745098,0.713725490196078,0.701960784313725,
    0.694117647058824,0.682352941176471,0.674509803921569,0.662745098039216,
    0.654901960784314,0.643137254901961,0.635294117647059,0.623529411764706,
    0.615686274509804,0.603921568627451,0.592156862745098,0.584313725490196,
    0.572549019607843,0.564705882352941,0.552941176470588,0.545098039215686,
    0.533333333333333,0.525490196078431,0.513725490196078,0.505882352941176,
    0.494117647058824,0.486274509803922,0.474509803921569,0.466666666666667,
    0.454901960784314,0.447058823529412,0.435294117647059,0.427450980392157,
    0.415686274509804,0.407843137254902,0.396078431372549,0.384313725490196,
    0.376470588235294,0.364705882352941,0.356862745098039,0.345098039215686,
    0.337254901960784,0.325490196078431,0.317647058823529,0.305882352941176,
    0.298039215686275,0.286274509803922,0.27843137254902,0.266666666666667,
    0.258823529411765,0.247058823529412,0.23921568627451,0.227450980392157,
    0.219607843137255,0.207843137254902,0.196078431372549,0.188235294117647,
    0.176470588235294,0.168627450980392,0.156862745098039,0.149019607843137,
    0.137254901960784,0.129411764705882,0.117647058823529,0.109803921568627,
    0.0980392156862745,0.0901960784313725,0.0784313725490196,0.0705882352941176,
    0.0588235294117647,0.0509803921568627,0.0392156862745098,0.0313725490196078,
    0.0196078431372549,0.0117647058823529,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

const Rcpp::List matlab_like2 = Rcpp::List::create(
  _["r"] = matlab_like2_red,
  _["g"] = matlab_like2_green,
  _["b"] = matlab_like2_blue
);
} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/matlab_like2.hpp <==
#ifndef R_COLOURVALUES_MATLAB_LIKE2_H
#define R_COLOURVALUES_MATLAB_LIKE2_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector matlab_like2_red = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0117647058823529,0.0196078431372549,
    0.0313725490196078,0.0392156862745098,0.0509803921568627,0.0588235294117647,
    0.0705882352941176,0.0784313725490196,0.0862745098039216,0.0980392156862745,
    0.109803921568627,0.117647058823529,0.129411764705882,0.137254901960784,
    0.149019607843137,0.156862745098039,0.168627450980392,0.176470588235294,
    0.188235294117647,0.196078431372549,0.207843137254902,0.215686274509804,
    0.227450980392157,0.235294117647059,0.247058823529412,0.254901960784314,
    0.266666666666667,0.274509803921569,0.286274509803922,0.294117647058824,
    0.305882352941176,0.313725490196078,0.325490196078431,0.333333333333333,
    0.345098039215686,0.352941176470588,0.364705882352941,0.372549019607843,
    0.384313725490196,0.392156862745098,0.403921568627451,0.411764705882353,
    0.423529411764706,0.431372549019608,0.443137254901961,0.450980392156863,
    0.462745098039216,0.470588235294118,0.482352941176471,0.490196078431373,
    0.501960784313725,0.509803921568627,0.52156862745098,0.529411764705882,
    0.541176470588235,0.549019607843137,0.56078431372549,0.568627450980392,
    0.576470588235294,0.588235294117647,0.6,0.607843137254902,
    0.619607843137255,0.627450980392157,0.63921568627451,0.647058823529412,
    0.658823529411765,0.666666666666667,0.67843137254902,0.686274509803922,
    0.698039215686274,0.705882352941177,0.717647058823529,0.725490196078431,
    0.733333333333333,0.745098039215686,0.756862745098039,0.764705882352941,
    0.776470588235294,0.784313725490196,0.796078431372549,0.803921568627451,
    0.815686274509804,0.823529411764706,0.835294117647059,0.843137254901961,
    0.854901960784314,0.862745098039216,0.874509803921569,0.882352941176471,
    0.890196078431372,0.901960784313726,0.913725490196078,0.92156862745098,
    0.933333333333333,0.941176470588235,0.952941176470588,0.96078431372549,
    0.972549019607843,0.980392156862745,0.992156862745098,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,0.992156862745098,
    0.980392156862745,0.972549019607843,0.96078431372549,0.952941176470588,
    0.941176470588235,0.933333333333333,0.92156862745098,0.913725490196078,
    0.901960784313726,0.890196078431372,0.882352941176471,0.874509803921569,
    0.862745098039216,0.854901960784314,0.843137254901961,0.835294117647059,
    0.823529411764706,0.815686274509804,0.803921568627451,0.796078431372549,
    0.784313725490196,0.776470588235294,0.764705882352941,0.756862745098039
  };

  const Rcpp::NumericVector matlab_like2_green = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0196078431372549,0.0392156862745098,
    0.0588235294117647,0.0784313725490196,0.0980392156862745,0.117647058823529,
    0.137254901960784,0.156862745098039,0.176470588235294,0.196078431372549,
    0.215686274509804,0.235294117647059,0.254901960784314,0.274509803921569,
    0.294117647058824,0.313725490196078,0.333333333333333,0.352941176470588,
    0.372549019607843,0.392156862745098,0.411764705882353,0.431372549019608,
    0.450980392156863,0.470588235294118,0.490196078431373,0.509803921568627,
    0.529411764705882,0.549019607843137,0.568627450980392,0.588235294117647,
    0.607843137254902,0.627450980392157,0.647058823529412,0.666666666666667,
    0.686274509803922,0.705882352941177,0.725490196078431,0.745098039215686,
    0.764705882352941,0.784313725490196,0.803921568627451,0.823529411764706,
    0.843137254901961,0.862745098039216,0.882352941176471,0.901960784313726,
    0.92156862745098,0.941176470588235,0.96078431372549,0.980392156862745,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,0.980392156862745,
    0.96078431372549,0.941176470588235,0.92156862745098,0.901960784313726,
    0.886274509803922,0.866666666666667,0.847058823529412,0.827450980392157,
    0.807843137254902,0.788235294117647,0.768627450980392,0.749019607843137,
    0.729411764705882,0.709803921568627,0.694117647058824,0.674509803921569,
    0.654901960784314,0.635294117647059,0.615686274509804,0.596078431372549,
    0.576470588235294,0.556862745098039,0.537254901960784,0.517647058823529,
    0.501960784313725,0.482352941176471,0.462745098039216,0.443137254901961,
    0.423529411764706,0.403921568627451,0.384313725490196,0.364705882352941,
    0.345098039215686,0.325490196078431,0.305882352941176,0.290196078431373,
    0.270588235294118,0.250980392156863,0.231372549019608,0.211764705882353,
    0.192156862745098,0.172549019607843,0.152941176470588,0.133333333333333,
    0.113725490196078,0.0980392156862745,0.0784313725490196,0.0588235294117647,
    0.0392156862745098,0.0196078431372549,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  const Rcpp::NumericVector matlab_like2_blue = {
    0.745098039215686,0.756862745098039,0.764705882352941,0.776470588235294,
    0.784313725490196,0.796078431372549,0.803921568627451,0.815686274509804,
    0.823529411764706,0.835294117647059,0.843137254901961,0.854901960784314,
    0.862745098039216,0.874509803921569,0.882352941176471,0.890196078431372,
    0.901960784313726,0.913725490196078,0.92156862745098,0.933333333333333,
    0.941176470588235,0.952941176470588,0.96078431372549,0.972549019607843,
    0.980392156862745,0.992156862745098,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,0.988235294117647,0.980392156862745,
    0.968627450980392,0.96078431372549,0.949019607843137,0.941176470588235,
    0.929411764705882,0.92156862745098,0.909803921568627,0.901960784313726,
    0.890196078431372,0.882352941176471,0.870588235294118,0.862745098039216,
    0.850980392156863,0.843137254901961,0.831372549019608,0.823529411764706,
    0.811764705882353,0.803921568627451,0.792156862745098,0.780392156862745,
    0.772549019607843,0.76078431372549,0.752941176470588,0.741176470588235,
    0.733333333333333,0.72156862745098,0.713725490196078,0.701960784313725,
    0.694117647058824,0.682352941176471,0.674509803921569,0.662745098039216,
    0.654901960784314,0.643137254901961,0.635294117647059,0.623529411764706,
    0.615686274509804,0.603921568627451,0.592156862745098,0.584313725490196,
    0.572549019607843,0.564705882352941,0.552941176470588,0.545098039215686,
    0.533333333333333,0.525490196078431,0.513725490196078,0.505882352941176,
    0.494117647058824,0.486274509803922,0.474509803921569,0.466666666666667,
    0.454901960784314,0.447058823529412,0.435294117647059,0.427450980392157,
    0.415686274509804,0.407843137254902,0.396078431372549,0.384313725490196,
    0.376470588235294,0.364705882352941,0.356862745098039,0.345098039215686,
    0.337254901960784,0.325490196078431,0.317647058823529,0.305882352941176,
    0.298039215686275,0.286274509803922,0.27843137254902,0.266666666666667,
    0.258823529411765,0.247058823529412,0.23921568627451,0.227450980392157,
    0.219607843137255,0.207843137254902,0.196078431372549,0.188235294117647,
    0.176470588235294,0.168627450980392,0.156862745098039,0.149019607843137,
    0.137254901960784,0.129411764705882,0.117647058823529,0.109803921568627,
    0.0980392156862745,0.0901960784313725,0.0784313725490196,0.0705882352941176,
    0.0588235294117647,0.0509803921568627,0.0392156862745098,0.0313725490196078,
    0.0196078431372549,0.0117647058823529,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  // const Rcpp::List matlab_like2 = Rcpp::List::create(
  //   _["r"] = matlab_like2_red,
  //   _["g"] = matlab_like2_green,
  //   _["b"] = matlab_like2_blue
  // );
} // namespace palette
} // namepsace colourvalues

#endif
